/* This file was generated by syncqt. */
#ifndef QT_QTWEBCHANNEL_VERSION_H
#define QT_QTWEBCHANNEL_VERSION_H

#define QTWEBCHANNEL_VERSION_STR "6.12.0"

#define QTWEBCHANNEL_VERSION 0x0601200

#endif // QT_QTWEBCHANNEL_VERSION_H
